@@ -3,7 +3,7 @@ BEGIN {
   $lib::absolute::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $lib::absolute::VERSION = '0.002';
+  $lib::absolute::VERSION = '0.003';
 }
 # ABSTRACT: Convert all paths in @INC to absolute paths
 
@@ -30,17 +30,7 @@ sub import {
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-lib::absolute - Convert all paths in @INC to absolute paths
-
-=head1 VERSION
-
-version 0.002
+=encoding utf8
 
 =head1 SYNOPSIS
 
@@ -53,8 +43,6 @@ version 0.002
 This package converts on load all your @INC path into absolute paths, if you have "." in your path, it gets additionally
 added again (and also get added as absolute path).
 
-=encoding utf8
-
 =head1 SUPPORT
 
 IRC
@@ -65,21 +53,9 @@ Repository
 
   http://github.com/Getty/p5-lib-absolute
   Pull request and additional contributors are welcome
-
+ 
 Issue Tracker
 
   http://github.com/Getty/p5-lib-absolute/issues
 
-=head1 AUTHOR
-
-Torsten Raudssus <torsten@raudss.us>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Torsten Raudssus.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
 
